import {useErrorStore} from '@/stores/error';
import type {
  AddViewConfig,
  FormValues,
  SchoolClassDetailResponseModel,
} from '../models';
import {fetchAuthenticated} from '../retrieveData';
import {getError, getSaveError, needMock, type SaveError} from '@/helpers/dataAccess';
import i18next from 'i18next';
import {fetchMockData, groupDetailResponse} from '@/helpers/mocks';

// eslint-disable-next-line
export const fetchSchoolClassAddViewConfig = async(): Promise<AddViewConfig> => {
  console.log('Not implemented');
  return {
    pages: [],
  };
};

// eslint-disable-next-line
export const createSchoolClass = async(values: FormValues): Promise<SaveError | null> => {
  console.log('Not implemented');
  return null;
};

export const fetchSchoolClass = async(schoolClass: string): Promise<SchoolClassDetailResponseModel | null> => {
  if (needMock) {
    return fetchMockData(groupDetailResponse, 'fetchSchoolClass');
  }

  const answer = await fetchAuthenticated(`/ucsschool/bff-groups/v1/school_class/${schoolClass}`);
  if (answer.status === 404) {
    return null;
  }
  const error = await getError(answer);
  if (error) {
    const errorStore = useErrorStore();
    const title = i18next.t('dataAccess.fetchGroup.error.title', {context: 'school_class'});
    errorStore.push({
      title,
      message: JSON.stringify(error.detail),
    });
    return Promise.reject(answer);
  }
  return await answer.json();
};

export const updateSchoolClass = async(url: string, values: FormValues): Promise<SaveError | null> => {
  if (needMock) {
    // TODO have the fail case in some way too
    return fetchMockData(null, 'updateSchoolClass');
  }

  const fixedProtocolUrl = url.replace(/https?:/, location.protocol);
  const answer = await fetchAuthenticated(`${fixedProtocolUrl}`, {
    method: 'PATCH',
    headers: {
      'Content-Type': 'application/json',
    },
    body: JSON.stringify(values),
  });
  return await getSaveError(answer, 'createWorkgroup');
};
